@@ -46,10 +46,22 @@ class InformationRetrievalScorer(Scorer):
 class ClassificationScorer(Scorer):
     def __call__(self, actual, predicted, **kwargs):
         return {
-            "macro_recall": macro(recall, actual, predicted),
-            "macro_precision": macro(precision, actual, predicted),
-            "macro_f1": macro(f1, actual, predicted),
-            "macro_em": macro(exact_match, actual, predicted)
+            # "macro_recall": macro(recall, actual, predicted),
+            # "macro_precision": macro(precision, actual, predicted),
+            # "macro_f1": macro(f1, actual, predicted),
+            "em": macro(exact_match, actual, predicted)
+        }
+
+
+
+
+
+
+@Scorer.register("qa")
+class ClassificationScorer(Scorer):
+    def __call__(self, actual, predicted, **kwargs):
+        return {
+            "em": macro(exact_match, actual, predicted)
         }
 
 
